# flake8: noqa

# import apis into api package
from telegram_assistant_connector.api.default_api import DefaultApi
from telegram_assistant_connector.api.telegram_connector_api import TelegramConnectorApi




# coding: utf-8

"""
    Mentortools Telegram Assistant API

    Mentortools telegram assistant connector

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from telegram_assistant_connector.api.telegram_connector_api import TelegramConnectorApi  # noqa: E501


class TestTelegramConnectorApi(unittest.IsolatedAsyncioTestCase):
    """TelegramConnectorApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = TelegramConnectorApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_telegram_connector_send_authorization_message(self) -> None:
        """Test case for telegram_connector_send_authorization_message

        Send authorization message  # noqa: E501
        """
        pass

    async def test_telegram_connector_send_message(self) -> None:
        """Test case for telegram_connector_send_message

        Send message  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Mentortools Telegram Assistant API

    Mentortools telegram assistant connector

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.1.0+2399831551"

# Define package exports
__all__ = [
    "DefaultApi",
    "TelegramConnectorApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "HTTPValidationError",
    "LocationInner",
    "SendMessagePayload",
    "ValidationError",
    "WrappedResponseBool",
    "WrappedResponseInt",
]

# import apis into sdk package
from telegram_assistant_connector.api.default_api import DefaultApi as DefaultApi
from telegram_assistant_connector.api.telegram_connector_api import TelegramConnectorApi as TelegramConnectorApi

# import ApiClient
from telegram_assistant_connector.api_response import ApiResponse as ApiResponse
from telegram_assistant_connector.api_client import ApiClient as ApiClient
from telegram_assistant_connector.configuration import Configuration as Configuration
from telegram_assistant_connector.exceptions import OpenApiException as OpenApiException
from telegram_assistant_connector.exceptions import ApiTypeError as ApiTypeError
from telegram_assistant_connector.exceptions import ApiValueError as ApiValueError
from telegram_assistant_connector.exceptions import ApiKeyError as ApiKeyError
from telegram_assistant_connector.exceptions import ApiAttributeError as ApiAttributeError
from telegram_assistant_connector.exceptions import ApiException as ApiException

# import models into sdk package
from telegram_assistant_connector.models.http_validation_error import HTTPValidationError as HTTPValidationError
from telegram_assistant_connector.models.location_inner import LocationInner as LocationInner
from telegram_assistant_connector.models.send_message_payload import SendMessagePayload as SendMessagePayload
from telegram_assistant_connector.models.validation_error import ValidationError as ValidationError
from telegram_assistant_connector.models.wrapped_response_bool import WrappedResponseBool as WrappedResponseBool
from telegram_assistant_connector.models.wrapped_response_int import WrappedResponseInt as WrappedResponseInt



# coding: utf-8

"""
    Mentortools Telegram Assistant API

    Mentortools telegram assistant connector

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from telegram_assistant_connector.models.send_message_payload import SendMessagePayload  # noqa: E501

class TestSendMessagePayload(unittest.TestCase):
    """SendMessagePayload unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SendMessagePayload:
        """Test SendMessagePayload
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SendMessagePayload`
        """
        model = SendMessagePayload()  # noqa: E501
        if include_optional:
            return SendMessagePayload(
                user_id = 56,
                text = '',
                attachments = [
                    ''
                    ]
            )
        else:
            return SendMessagePayload(
                user_id = 56,
                text = '',
        )
        """

    def testSendMessagePayload(self):
        """Test SendMessagePayload"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Mentortools Telegram Assistant API

    Mentortools telegram assistant connector

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from telegram_assistant_connector.models.http_validation_error import HTTPValidationError
from telegram_assistant_connector.models.location_inner import LocationInner
from telegram_assistant_connector.models.send_message_payload import SendMessagePayload
from telegram_assistant_connector.models.validation_error import ValidationError
from telegram_assistant_connector.models.wrapped_response_bool import WrappedResponseBool
from telegram_assistant_connector.models.wrapped_response_int import WrappedResponseInt
